@@ -1,7 +1,10 @@
 import os
 import numpy as np
 from PIL import Image
-from Functions import *
+
+def func(x):
+    #return -np.log(x*(-1)/255.1 + 1)
+    return - 1/ ((1 * x/256)-1) - 1
 
 def NumOCR(path, label=None, debug=False, show=False):
 
